cis_config: CisAsciiFileInput Class Reference

cis_config

Public Member Functions | List of all members
CisAsciiFileInput Class Reference

C++ interface to cisAsciiFileInput_t functionality. The CisAsciiFileInput class is a basic wrapper around the C cisAsciiFileInput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file input operations. More...

`#include <CisInterface.hpp>`

Inheritance diagram for CisAsciiFileInput:

## Public Member Functions
| CisAsciiFileInput (const char *name)
| Constructor for CisAsciiFileInput. More...
| CisAsciiFileInput (cisInput_t x)
| Empty constructor for inheritance.
int | recv_line (char *line, const size_t n)
| Receive a single line from an associated file or queue. See af_recv_line in CisInterface.h for details. More...
Public Member Functions inherited from CisInput
| CisInput (const char *name)
| Constructor for CisInput. More...
| CisInput (cisInput_t x)
| Empty constructor for inheritance.
| CisInput (const char *name, const char *fmt)
| Constructor for CisInput with format. More...
void | _destroy_pi ()
| Alias to allow freeing of underlying C struct at the class level.
| ~CisInput ()
| Destructor for CisInput. See cis_free in CisInterface.h for details.
cisInput_t | pi ()
| Return the cisInput_t structure. More...
int | recv (char *data, const size_t len)
| Receive a message shorter than CIS_MSG_MAX from the input queue. See cis_recv in CisInterface.h for additional details. More...
int | recv (const int nargs,...)
| Receive and parse a message shorter than CIS_MSG_MAX from the input queue. See cisRecv from CisInterface.h for details. More...
int | recv_nolimit (char **data, const size_t len)
| Receive a message larger than CIS_MSG_MAX from the input queue. See cis_recv_nolimit in CisInterface.h for additional details. More...
int | recv_nolimit (const int nargs,...)
| Receive and parse a message larger than CIS_MSG_MAX from the input queue. See cisRecv_nolimit from CisInterface.h for details. More...

## Detailed Description

C++ interface to cisAsciiFileInput_t functionality. The CisAsciiFileInput class is a basic wrapper around the C cisAsciiFileInput_t structure and associated functions from the CisInterface.h header. It provides the user with C++ style access to basic ASCII file input operations.

## Constructor & Destructor Documentation

## ◆ CisAsciiFileInput()

CisAsciiFileInput::CisAsciiFileInput | ( | const char * | name | ) |
| inline

Constructor for CisAsciiFileInput.

Parameters

  [in] | name | constant character pointer to the name of an input channel.

## Member Function Documentation

## ◆ recv_line()

int CisAsciiFileInput::recv_line | ( | char * | line,
|  | const size_t | n
| ) |  |
| inline

Receive a single line from an associated file or queue. See af_recv_line in CisInterface.h for details.

Parameters

  [out] | line | character pointer to allocate memory where the received line should be stored.
  [in] | n | size_t Size of the allocated memory block in bytes.

Returns
  int Number of bytes read/received. Negative values indicate that there was either an error or the EOF message was received.

The documentation for this class was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/interface/CisInterface.hpp